161,497 Commits over 4,597 Days - 1.46cph!

23 Days Ago
main -> pt_boat_turret_rewrite
23 Days Ago
Only send turret targets rather than every single turret movement We are effectively predicting the turret movement on the client with the server reconcilling it 1.83 -> 0.20 aim messages/s per idle turret ~46 -> ~7 B/s per turret per player On a 122 player server: roughly ~105 KB/s less outbound (~9GB a day). 6% reduction of all outbound game data
23 Days Ago
Formatting
23 Days Ago
first pass on tattoo layering - 2 layers, 1 "base" layer which is fixed onto the player model, 1 which is edited during a painting session - tattoo compositor merges the editing layer onto the base layer when exiting the menu or saving - fade is applied to base layer, and baked into the png when merging downwards - rads add fade to the base layer visually with a parameter, which is only baked in during a merge - reworked to accomodate a separate player sending the tattoo edits to the other for saving (bc tattoo chair eventually) - moved more code to serverside to allow for direct painting communication between 2 clients
23 Days Ago
Refactor and optimize LookAtIOEnt, avoid various allocs when wiring or updating battery info, avoid physics query every frame for turret interference
23 Days Ago
merge from gunfiring_optims
23 Days Ago
Fixed holding a gun searching the whole inventory every frame for reload ammo types Holding a gun with a full inventory: 0.06ms -> ~0.01ms
23 Days Ago
Initial pass, helper scene/player model guide prefab for easier balancing
Rin
23 Days Ago
merge from hackable_crate_icon
Rin
23 Days Ago
Updated hackable crate map icon
23 Days Ago
Merge from vcc
23 Days Ago
merge from gunfiring_optims
23 Days Ago
Fixed issues from the far shot and shell replay changes
23 Days Ago
Wallpaper health was included with every building block, even those without wallpaper Saves 10 B per building block
23 Days Ago
More prefab fixes
23 Days Ago
Optimize LookAtPlant and LookAtPlanter, only rebuild if data changed
23 Days Ago
Stop muzzle flash light casting any shadows past 60 meters cause it's wasteful Added MaxShadowDistance to LightLOD, default 0 so existing lights aren't changed
24 Days Ago
Fix head jitter when playing turn in place anims
24 Days Ago
Pack the tree billboard lists sent to joining players Each cell now sends its prefabs once, ids as deltas from the previous tree and positions as raw halves instead of a nested message per tree ~30 -> ~16 bytes per tree, roughly 1.8 MB -> 0.9 MB per player join on a full map
24 Days Ago
▍ ▄▍▉▆▌ ▌██▉ ▊▌▍▉▇▉▋█▌▍▉▄▄▅▌▇█▄▌▍▌▇
24 Days Ago
▋ ▆▋▇▉▊▅█ ▊▇▆▆▋█▅▋▆ ▊▊▉ ▋▊▄▄▇▉▆▆ ▅▄ ▊▌▍▋ ▍▇ ▉▉█▇▄▅▆▉ ▌▅▄▇█ ▇▋▄ ▍▉▇ ▅▆▋▄▄▇▌▇▉ ▋█▆▄▉▌▆▊▆▆▉ ▊█▉▅▆▉ ▌▌▋▇ ▉ ▌▇▇ ▋▄▋▉▇▄
24 Days Ago
Reviewed the 3P gun effects we spawn for distant shots: - Muzzle particles don't emit past 60m anymore, you only get the muzzle light and the sound - Shells aren't spawned past 15m Unchanged when using scopes and binoculars, the distances are stretched based on zoom scale
24 Days Ago
Item icon, delete some unused uzi fbx files at the root of the assets folder
24 Days Ago
merge from snowmobile_wheel_fix
24 Days Ago
Fixed snowmobile wheels jittering at standstill due to physics noise Before: https://files.facepunch.com/raul/2026/October/13_14-12-FrailCobra.mp4 After: https://files.facepunch.com/raul/2026/October/13_14-14-RedBlacknorwegianelkhound.mp4
24 Days Ago
Texture fixes
24 Days Ago
Send animal look direction in an RPC rather than with SendNetworkUpdate Animals with look animators were running network updates crazy often rather than just sending the look over This was especially bad with cows, wolfs, sheep and bulls Worst offender is cow at ~144 bytes per look update (network update). ~350 B/s per cow per player -> ~60 B/s
24 Days Ago
merge from main
24 Days Ago
Set all the gun firing effects warmed up amount accordingly Estimated +21MB vs main, still around -29MB overall after removing the 3900 useless thrown projectiles
24 Days Ago
Release pad run/crouch toggles when keyboard/mouse is used, so a pad latch can't carry into keyboard play
24 Days Ago
Various prefab fixes
24 Days Ago
Fix editor NRE debug
24 Days Ago
mag_drop_fixes -> main
24 Days Ago
Stop SpaceLR and M15 mags sticking to the bone
24 Days Ago
Gun attack effects can now be recycled before their tail sound finishes, means we only have to warm up half the amount we'd need to
24 Days Ago
Cleanup
24 Days Ago
merge from main
24 Days Ago
Skip the gamepad vehicle action set lookup when no Steam Input controller is active
24 Days Ago
Only send waterwheel network updates when its actually changed (at low speed) Saves ~76 B per skipped update per nearby player
24 Days Ago
Merge from main
24 Days Ago
Clear potential stale gamepad inventory cursors in edit mode
24 Days Ago
Tooltip bind lookup fix
24 Days Ago
Added replayInPlace to EffectRecycle, lets us flag effects that can be replayed in place instead of popping and retiring a pooled copy every time Applied to AK first and 3rd person shell eject effects for now, ~0.13ms -> ~0.04ms per shot Also means we'll only have to prewarm a handful of shell particle prefabs for all the guns
24 Days Ago
Adding dweller mace viewmodel rig
24 Days Ago
Merge from main
24 Days Ago
merge from main
24 Days Ago
Use Facepunch.Steamworks GetPngAnalogActionGlyph for stick/trigger glyphs, remove the now unnecessary hacky workaround
24 Days Ago
Merge from main
24 Days Ago
Fix motion vector pass being culled when ocean is present
24 Days Ago
Merge from main (actually latest this time)